==> jc-1.4.0.tar.gz: javax/crypto/spec/RC2ParameterSpec.h <==
// public class javax.crypto.spec.RC2ParameterSpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6ec0a11777fc9640 javax_crypto_spec_RC2ParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_RC2ParameterSpec_H_
#define _JC_javax_crypto_spec_RC2ParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_RC2ParameterSpec$sub_refs	_jc_javax_crypto_spec_RC2ParameterSpec$sub_refs;
typedef struct _jc_javax_crypto_spec_RC2ParameterSpec$sub_nonrefs	_jc_javax_crypto_spec_RC2ParameterSpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_RC2ParameterSpec$refs	_jc_javax_crypto_spec_RC2ParameterSpec$refs;
typedef struct _jc_javax_crypto_spec_RC2ParameterSpec$nonrefs	_jc_javax_crypto_spec_RC2ParameterSpec$nonrefs;
typedef struct _jc_javax_crypto_spec_RC2ParameterSpec$object	_jc_javax_crypto_spec_RC2ParameterSpec$object;

typedef struct _jc_javax_crypto_spec_RC2ParameterSpec$fields_struct	_jc_javax_crypto_spec_RC2ParameterSpec$fields_struct;
typedef const struct _jc_javax_crypto_spec_RC2ParameterSpec$vmethods	_jc_javax_crypto_spec_RC2ParameterSpec$vmethods;
typedef const struct _jc_javax_crypto_spec_RC2ParameterSpec$vtable	_jc_javax_crypto_spec_RC2ParameterSpec$vtable;
typedef const struct _jc_javax_crypto_spec_RC2ParameterSpec$vtype	_jc_javax_crypto_spec_RC2ParameterSpec$vtype;

// Class fields structure
struct _jc_javax_crypto_spec_RC2ParameterSpec$fields_struct {
	jint	RC2__5fIV__5fLENGTH;
};
extern _jc_javax_crypto_spec_RC2ParameterSpec$fields_struct _jc_javax_crypto_spec_RC2ParameterSpec$class_fields;

// Constructors
extern void _jc_javax_crypto_spec_RC2ParameterSpec$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *, jint);
extern void _jc_javax_crypto_spec_RC2ParameterSpec$method$_init$85a20918701c98c3(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *, jint, struct _jc_byte_array *);
extern void _jc_javax_crypto_spec_RC2ParameterSpec$method$_init$c24aea43a39f620a(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *, jint, struct _jc_byte_array *, jint);

// Virtual methods
extern jboolean _jc_javax_crypto_spec_RC2ParameterSpec$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_javax_crypto_spec_RC2ParameterSpec$method$getEffectiveKeyBits$56e1f090fd9daafa(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *);
extern _jc_byte_array *_jc_javax_crypto_spec_RC2ParameterSpec$method$getIV$4134a0c13b73072e(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *);
extern jint _jc_javax_crypto_spec_RC2ParameterSpec$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_RC2ParameterSpec$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_crypto_spec_RC2ParameterSpec$method_info$getEffectiveKeyBits$56e1f090fd9daafa;
extern _jc_method _jc_javax_crypto_spec_RC2ParameterSpec$method_info$getIV$4134a0c13b73072e;
extern _jc_method _jc_javax_crypto_spec_RC2ParameterSpec$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_javax_crypto_spec_RC2ParameterSpec$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *, struct _jc_java_lang_Object$object *);
	jint	(*getEffectiveKeyBits$56e1f090fd9daafa)(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *);
	_jc_byte_array	*(*getIV$4134a0c13b73072e)(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *);
};

// Vtable
struct _jc_javax_crypto_spec_RC2ParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_RC2ParameterSpec$vmethods	javax_crypto_spec_RC2ParameterSpec;
};

// Vtype
struct _jc_javax_crypto_spec_RC2ParameterSpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_RC2ParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_RC2ParameterSpec$sub_refs {
	_jc_byte_array	*iv;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_RC2ParameterSpec$refs {
    _jc_javax_crypto_spec_RC2ParameterSpec$sub_refs	javax_crypto_spec_RC2ParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_RC2ParameterSpec$sub_nonrefs {
	jint	effectiveKeyBits;
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_RC2ParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_RC2ParameterSpec$sub_nonrefs	javax_crypto_spec_RC2ParameterSpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_RC2ParameterSpec$object {
	_jc_javax_crypto_spec_RC2ParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_RC2ParameterSpec$vtype	*vtype;
	_jc_javax_crypto_spec_RC2ParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_RC2ParameterSpec$vtype _jc_javax_crypto_spec_RC2ParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_RC2ParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_RC2ParameterSpec$class_object;

#endif	/* _JC_javax_crypto_spec_RC2ParameterSpec_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/spec/RC2ParameterSpec.h <==
// public class javax.crypto.spec.RC2ParameterSpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6ec0a11777fc9640 javax_crypto_spec_RC2ParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_RC2ParameterSpec_H_
#define _JC_javax_crypto_spec_RC2ParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_RC2ParameterSpec$sub_refs	_jc_javax_crypto_spec_RC2ParameterSpec$sub_refs;
typedef struct _jc_javax_crypto_spec_RC2ParameterSpec$sub_nonrefs	_jc_javax_crypto_spec_RC2ParameterSpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_RC2ParameterSpec$refs	_jc_javax_crypto_spec_RC2ParameterSpec$refs;
typedef struct _jc_javax_crypto_spec_RC2ParameterSpec$nonrefs	_jc_javax_crypto_spec_RC2ParameterSpec$nonrefs;
typedef struct _jc_javax_crypto_spec_RC2ParameterSpec$object	_jc_javax_crypto_spec_RC2ParameterSpec$object;

typedef struct _jc_javax_crypto_spec_RC2ParameterSpec$fields_struct	_jc_javax_crypto_spec_RC2ParameterSpec$fields_struct;
typedef const struct _jc_javax_crypto_spec_RC2ParameterSpec$vmethods	_jc_javax_crypto_spec_RC2ParameterSpec$vmethods;
typedef const struct _jc_javax_crypto_spec_RC2ParameterSpec$vtable	_jc_javax_crypto_spec_RC2ParameterSpec$vtable;
typedef const struct _jc_javax_crypto_spec_RC2ParameterSpec$vtype	_jc_javax_crypto_spec_RC2ParameterSpec$vtype;

// Class fields structure
struct _jc_javax_crypto_spec_RC2ParameterSpec$fields_struct {
	jint	RC2__5fIV__5fLENGTH;
};
extern _jc_javax_crypto_spec_RC2ParameterSpec$fields_struct _jc_javax_crypto_spec_RC2ParameterSpec$class_fields;

// Constructors
extern void _jc_javax_crypto_spec_RC2ParameterSpec$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_spec_RC2ParameterSpec$method$_init$85a20918701c98c3(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *, jint, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_spec_RC2ParameterSpec$method$_init$c24aea43a39f620a(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *, jint, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_crypto_spec_RC2ParameterSpec$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_crypto_spec_RC2ParameterSpec$method$getEffectiveKeyBits$56e1f090fd9daafa(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_javax_crypto_spec_RC2ParameterSpec$method$getIV$4134a0c13b73072e(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_crypto_spec_RC2ParameterSpec$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_RC2ParameterSpec$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_crypto_spec_RC2ParameterSpec$method_info$getEffectiveKeyBits$56e1f090fd9daafa;
extern _jc_method _jc_javax_crypto_spec_RC2ParameterSpec$method_info$getIV$4134a0c13b73072e;
extern _jc_method _jc_javax_crypto_spec_RC2ParameterSpec$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_javax_crypto_spec_RC2ParameterSpec$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*getEffectiveKeyBits$56e1f090fd9daafa)(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getIV$4134a0c13b73072e)(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_crypto_spec_RC2ParameterSpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_crypto_spec_RC2ParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_RC2ParameterSpec$vmethods	javax_crypto_spec_RC2ParameterSpec;
};

// Vtype
struct _jc_javax_crypto_spec_RC2ParameterSpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_RC2ParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_RC2ParameterSpec$sub_refs {
	_jc_byte_array	*iv;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_RC2ParameterSpec$refs {
    _jc_javax_crypto_spec_RC2ParameterSpec$sub_refs	javax_crypto_spec_RC2ParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_RC2ParameterSpec$sub_nonrefs {
	jint	effectiveKeyBits;
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_RC2ParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_RC2ParameterSpec$sub_nonrefs	javax_crypto_spec_RC2ParameterSpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_RC2ParameterSpec$object {
	_jc_javax_crypto_spec_RC2ParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_RC2ParameterSpec$vtype	*vtype;
	_jc_javax_crypto_spec_RC2ParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_RC2ParameterSpec$vtype _jc_javax_crypto_spec_RC2ParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_RC2ParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_RC2ParameterSpec$class_object;

#endif	/* _JC_javax_crypto_spec_RC2ParameterSpec_H_ */
